@@ -1,5 +1,6 @@
 #' Set Alpha Vantage API Key
 #'
+#' Requires the alphavantager packager to use.
 #' @param api_key Optionally passed parameter to set Alpha Vantage `api_key`.
 #'
 #' @return Returns invisibly the currently set `api_key`
@@ -14,15 +15,15 @@
 #' @examples
 #'
 #' \dontrun{
+#' if (rlang::is_installed("alphavantager")) {
 #' av_api_key(api_key = "foobar")
 #' }
+#' }
 #'
 #' @name av_api_key
 #' @export
 av_api_key <- function(api_key) {
-    if(!requireNamespace("alphavantager", quietly = TRUE)) {
-        stop("alphavantager must be installed to use this functionality.", call. = FALSE)
-    }
+    rlang::check_installed("alphavantager", "to use the alphavantager API.")
     alphavantager::av_api_key(api_key)
 }
 
